@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2015 Adrien Vergé
+ *  Copyright (c) 2015 Adrien Vergé
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@
  * Fixed size of the buffer for outgoing HTTP requests.
  * Initial size of the buffer for incoming HTTP responses.
  */
-#define HTTP_BUFFER_SIZE 0x8000
+#define HTTP_BUFFER_SIZE 0x10000
 
 
 /*
@@ -90,13 +90,12 @@ int http_send(struct tunnel *tunnel, const char *request, ...)
 		char password[3 * PASSWORD_SIZE + 1];
 
 		url_encode(password, tunnel->config->password);
-		pwstart = strstr(logbuffer, password);
 
-		if (pwstart != NULL) {
+		while ((pwstart = strstr(logbuffer, password))) {
 			int pos, pwlen, i;
 
 			pos = pwstart - logbuffer;
-			pwlen = strlen(tunnel->config->password);
+			pwlen = strlen(password);
 			for (i = pos; i < pos + pwlen; i++)
 				logbuffer[i] = '*';
 		}
@@ -375,7 +374,6 @@ end:
 static int get_action_url(const char *buf, const char *key,
                           char *retbuf, size_t retbuflen)
 {
-
 	int ret = -1;
 	char *tokens;
 	size_t keylen = strlen(key);
@@ -840,7 +838,7 @@ static int parse_xml_config(struct tunnel *tunnel, const char *buffer)
 		if (xml_find(' ', "domain=", val, 1)) {
 			tunnel->ipv4.dns_suffix
 			        = xml_get(xml_find(' ', "domain=", val, 1));
-			log_debug("found dns suffix %s in xml config\n",
+			log_debug("Found dns suffix %s in xml config\n",
 			          tunnel->ipv4.dns_suffix);
 			break;
 		}
@@ -851,7 +849,7 @@ static int parse_xml_config(struct tunnel *tunnel, const char *buffer)
 	while ((val = xml_find('<', "dns", val, 2))) {
 		if (xml_find(' ', "ip=", val, 1)) {
 			dns_server = xml_get(xml_find(' ', "ip=", val, 1));
-			log_debug("found dns server %s in xml config\n", dns_server);
+			log_debug("Found dns server %s in xml config\n", dns_server);
 			if (!tunnel->ipv4.ns1_addr.s_addr)
 				tunnel->ipv4.ns1_addr.s_addr = inet_addr(dns_server);
 			else if (!tunnel->ipv4.ns2_addr.s_addr)
