@@ -270,11 +270,13 @@ static int pppd_run(struct tunnel *tunnel)
 				 * of our local IP address, even if the local IP address
 				 * was specified in an option.
 				 *
-				 * This option attempts to fix this:
+				 * pppd < 2.5.0 requires this option to avoid this error:
 				 *     Peer refused to agree to our IP address
-				 *
-				 * Yet, this doesn't make sense: we do not specify
-				 * a local IP address, and we use noipdefault.
+				 * This doesn't make sense to me. I feel it should be the
+				 * default because:
+				 * 1. we do not specify a local IP address,
+				 * 2. we use option noipdefault to specifically ask the
+				 *    peer to supply the local IP address.
 				 */
 				"ipcp-accept-local",
 				"noaccomp",
@@ -293,6 +295,23 @@ static int pppd_run(struct tunnel *tunnel)
 					return 1;
 				}
 		}
+		if (tunnel->config->pppd_accept_remote)
+			/*
+			 * With this option, pppd will accept the peer's idea of its
+			 * (remote) IP address, even if the remote IP address was
+			 * specified in an option.
+			 *
+			 * pppd ≥ 2.5.0 requires this option to avoid this error:
+			 *     Peer refused to agree to his IP address
+			 * This makes sense.
+			 *
+			 * Unfortunately, pppd < 2.5.0 does not like this option.
+			 * Again, this doesn't make sense to me.
+			 */
+			if (ofv_append_varr(&pppd_args, "ipcp-accept-remote")) {
+				free(pppd_args.data);
+				return 1;
+			}
 		if (tunnel->config->pppd_use_peerdns)
 			if (ofv_append_varr(&pppd_args, "usepeerdns")) {
 				free(pppd_args.data);
@@ -355,25 +374,6 @@ static int pppd_run(struct tunnel *tunnel)
 				return 1;
 			}
 		}
-		if (tunnel->config->pppd_accept_remote)
-			/*
-			 * With this option, pppd will accept the peer's idea of
-			 * its (remote) IP address, even if the remote IP address
-			 * was specified in an option.
-			 *
-			 * This option attempts to fix this with PPP 2.5.0:
-			 *     Peer refused to agree to his IP address
-			 *
-			 * Currently (always?) breaks on macOS with:
-			 *     Could not get current default route
-			 *     (Parsing /proc/net/route failed).
-			 *     Protecting tunnel route has failed.
-			 *     But this can be working except for some cases.
-			 */
-			if (ofv_append_varr(&pppd_args, "ipcp-accept-remote")) {
-				free(pppd_args.data);
-				return 1;
-			}
 #endif
 #if HAVE_USR_SBIN_PPP
 		if (tunnel->config->ppp_system) {
@@ -808,7 +808,7 @@ static int tcp_connect(struct tunnel *tunnel)
 	log_debug("server_addr: %s\n", inet_ntoa(server.sin_addr));
 	log_debug("server_port: %u\n", ntohs(server.sin_port));
 	server.sin_family = AF_INET;
-	memset(&(server.sin_zero), '\0', 8);
+	memset(&(server.sin_zero), 0, sizeof(server.sin_zero));
 	log_debug("gateway_ip: %s\n", inet_ntoa(tunnel->config->gateway_ip));
 	log_debug("gateway_port: %u\n", tunnel->config->gateway_port);
 
@@ -840,7 +840,7 @@ static int tcp_connect(struct tunnel *tunnel)
 		// be careful not to fetch too many bytes at once
 		const char *response = NULL;
 
-		memset(&(request), '\0', sizeof(request));
+		memset(&(request), 0, sizeof(request));
 		for (int j = 0; response == NULL; j++) {
 			if (j >= ARRAY_SIZE(request) - 1) {
 				log_error("Proxy response is unexpectedly large and cannot fit in the %lu-bytes buffer.\n",
